@@ -1,4 +1,4 @@
-"""
+'''
 //  -------------------------------------------------------------
 //  author        Giga
 //  project       qeeqbox/honeypots
@@ -8,7 +8,7 @@
 //  -------------------------------------------------------------
 //  contributors list qeeqbox/honeypots/graphs/contributors
 //  -------------------------------------------------------------
-"""
+'''
 
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
@@ -20,17 +20,18 @@ from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
 from dns.resolver import Resolver
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
 
 
 class QDNSServer():
-    def __init__(self, ip=None, port=None, username=None, password=None, resolver_addresses=None, config=''):
+    def __init__(self, ip=None, port=None, username=None, password=None, resolver_addresses=None, mocking=False, config=''):
         self.auto_disabled = None
         self.resolver_addresses = resolver_addresses or [('8.8.8.8', 53)]
         self.process = None
         self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
         self.config = config
+        self.mocking = mocking or ''
         self.ip = None
         self.port = None
         self.username = None
@@ -78,33 +79,39 @@ class QDNSServer():
         reactor.run()
 
     def run_server(self, process=False, auto=False):
+        status = 'error'
+        run = False
         if process:
             if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
-                    self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--config', str(self.config), '--uuid', str(self.uuid)])
-                    if self.process.poll() is None:
-                        self.logs.info(["servers", {'server': 'dns_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port}])
-                    else:
-                        self.logs.info(["servers", {'server': 'dns_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port}])
-                else:
-                    self.logs.info(["servers", {'server': 'dns_server', 'action': 'setup', 'status': 'error', 'ip': self.ip, 'port': self.port}])
+                    run = True
             elif self.close_port() and self.kill_server():
-                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--config', str(self.config), '--uuid', str(self.uuid)])
-                if self.process.poll() is None:
-                    self.logs.info(["servers", {'server': 'dns_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port}])
-                else:
-                    self.logs.info(["servers", {'server': 'dns_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port}])
+                run = True
+
+            if run:
+                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
+                if self.process.poll() is None and check_if_server_is_running(self.uuid):
+                    status = 'success'
+
+            self.logs.info(['servers', {'server': 'dns_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port}])
+
+            if status == 'success':
+                return True
+            else:
+                self.kill_server()
+                return False
         else:
             self.dns_server_main()
+        return None
 
     def test_server(self, ip=None, port=None, domain=None):
         try:
             res = Resolver(configure=False)
             res.nameservers = [self.ip]
             res.port = self.port
-            temp_domain = domain or "example.org"
+            temp_domain = domain or 'example.org'
             r = res.query(temp_domain, 'a')
         except BaseException:
             pass
