@@ -1,4 +1,4 @@
-"""
+'''
 //  -------------------------------------------------------------
 //  author        Giga
 //  project       qeeqbox/honeypots
@@ -8,7 +8,7 @@
 //  -------------------------------------------------------------
 //  contributors list qeeqbox/honeypots/graphs/contributors
 //  -------------------------------------------------------------
-"""
+'''
 
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
@@ -22,7 +22,7 @@ from os import path
 from struct import unpack, pack
 from binascii import unhexlify, hexlify
 from pymssql import connect as pconnect
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
 from ldap3 import Server, Connection, ALL
 from time import sleep
@@ -66,33 +66,33 @@ class QLDAPServer():
 
             def connectionMade(self):
                 self._state = 1
-                _q_s.logs.info(["servers", {'server': 'ldap_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
 
             def parse_ldap_packet(self, data):
 
                 #                 V
                 # 30[20] 0201[02] 60[1b] 0201[03] 04[0a] 7379736261636b757031 [80][0a] 7379736261636b757032
 
-                username = ""
-                password = ""
+                username = ''
+                password = ''
                 username_start = 0
                 username_end = 0
                 password_start = 0
                 password_end = 0
                 try:
-                    version = data.find(b"\x02\x01\x03")
+                    version = data.find(b'\x02\x01\x03')
                     if version > 0:
                         username_start = version + 5
-                        username_end = unpack("b", data[version + 4:username_start])[0] + username_start
+                        username_end = unpack('b', data[version + 4:username_start])[0] + username_start
                         username = data[username_start:username_end]
                         auth_type = data[username_end]
                         if auth_type == 0x80:
                             if data[username_end + 1] == 0x82:
                                 password_start = username_end + 4
-                                password_end = unpack(">H", data[username_end + 2:username_end + 4])[0] + username_end + 4
+                                password_end = unpack('>H', data[username_end + 2:username_end + 4])[0] + username_end + 4
                             else:
                                 password_start = username_end + 2
-                                password_end = unpack("b", data[username_end + 2:username_end + 3])[0] + username_start + 2
+                                password_end = unpack('b', data[username_end + 2:username_end + 3])[0] + username_start + 2
                             password = data[password_start:password_end]
                 except BaseException:
                     pass
@@ -105,23 +105,23 @@ class QLDAPServer():
                     username, password = self.parse_ldap_packet(data)
                     username = self.check_bytes(username)
                     password = self.check_bytes(password)
-                    if username != "" or password != "":
+                    if username != '' or password != '':
                         if username == _q_s.username and password == _q_s.password:
-                            _q_s.logs.info(["servers", {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
+                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
                         else:
-                            _q_s.logs.info(["servers", {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
-                    self.transport.write(unhexlify(b"300c02010165070a013204000400"))
+                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                    self.transport.write(unhexlify(b'300c02010165070a013204000400'))
                 elif self._state == 2:
                     self._state = 3
                     username, password = self.parse_ldap_packet(data)
                     username = self.check_bytes(username)
                     password = self.check_bytes(password)
-                    if username != "" or password != "":
+                    if username != '' or password != '':
                         if username == _q_s.username and password == _q_s.password:
-                            _q_s.logs.info(["servers", {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
+                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
                         else:
-                            _q_s.logs.info(["servers", {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
-                    self.transport.write(unhexlify(b"300c02010265070a013204000400"))
+                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                    self.transport.write(unhexlify(b'300c02010265070a013204000400'))
                 else:
                     self.transport.loseConnection()
 
@@ -134,24 +134,29 @@ class QLDAPServer():
         reactor.run()
 
     def run_server(self, process=False, auto=False):
+        status = 'error'
+        run = False
         if process:
             if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
-                    self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
-                    if self.process.poll() is None:
-                        self.logs.info(["servers", {'server': 'ldap_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
-                    else:
-                        self.logs.info(["servers", {'server': 'ldap_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
-                else:
-                    self.logs.info(["servers", {'server': 'ldap_server', 'action': 'setup', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+                    run = True
             elif self.close_port() and self.kill_server():
+                run = True
+
+            if run:
                 self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
-                if self.process.poll() is None:
-                    self.logs.info(["servers", {'server': 'ldap_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
-                else:
-                    self.logs.info(["servers", {'server': 'ldap_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+                if self.process.poll() is None and check_if_server_is_running(self.uuid):
+                    status = 'success'
+
+            self.logs.info(['servers', {'server': 'ldap_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+
+            if status == 'success':
+                return True
+            else:
+                self.kill_server()
+                return False
         else:
             self.ldap_server_main()
 
